# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.pydantic_utilities import pydantic_v1
from ...core.request_options import RequestOptions
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.athena_assistant_reponse import AthenaAssistantReponse
from ...types.athena_assistant_request import AthenaAssistantRequest

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class AthenaAssistantClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def batch(
        self,
        *,
        request: typing.Sequence[AthenaAssistantRequest],
        request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[AthenaAssistantReponse]:
        """
        Call the Athena assistant with batched requests and return the results.

        Parameters
        ----------
        request : typing.Sequence[AthenaAssistantRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[AthenaAssistantReponse]
            Successful Response

        Examples
        --------
        from athena import AthenaAssistantConfig, AthenaAssistantRequest, Tool
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.agents.athena_assistant.batch(
            request=[
                AthenaAssistantRequest(
                    config=AthenaAssistantConfig(
                        enabled_tools=[Tool.SEARCH],
                    ),
                    messages=[],
                )
            ],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/agents/athena-assistant/batch",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.List[AthenaAssistantReponse], _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def invoke(
        self, *, request: AthenaAssistantRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> AthenaAssistantReponse:
        """
        Call the Athena Assistant agent synchronously.

        Call the agent with the messages list, wait for the agent to complete,
        and return the result.

        Parameters
        ----------
        request : AthenaAssistantRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AthenaAssistantReponse
            Successful Response

        Examples
        --------
        from athena import AthenaAssistantConfig, AthenaAssistantRequest, Tool
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.agents.athena_assistant.invoke(
            request=AthenaAssistantRequest(
                config=AthenaAssistantConfig(
                    enabled_tools=[Tool.SEARCH],
                ),
                messages=[],
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/agents/athena-assistant/invoke",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(AthenaAssistantReponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def stream_events(
        self, *, request: AthenaAssistantRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> AthenaAssistantReponse:
        """
        Call the Athena assistant and stream events.

        Parameters
        ----------
        request : AthenaAssistantRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AthenaAssistantReponse
            Successful Response

        Examples
        --------
        from athena import AthenaAssistantConfig, AthenaAssistantRequest, Tool
        from athena.client import Athena

        client = Athena(
            api_key="YOUR_API_KEY",
        )
        client.agents.athena_assistant.stream_events(
            request=AthenaAssistantRequest(
                config=AthenaAssistantConfig(
                    enabled_tools=[Tool.SEARCH],
                ),
                messages=[],
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/v0/agents/athena-assistant/stream_events",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(AthenaAssistantReponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncAthenaAssistantClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def batch(
        self,
        *,
        request: typing.Sequence[AthenaAssistantRequest],
        request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[AthenaAssistantReponse]:
        """
        Call the Athena assistant with batched requests and return the results.

        Parameters
        ----------
        request : typing.Sequence[AthenaAssistantRequest]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[AthenaAssistantReponse]
            Successful Response

        Examples
        --------
        from athena import AthenaAssistantConfig, AthenaAssistantRequest, Tool
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.agents.athena_assistant.batch(
            request=[
                AthenaAssistantRequest(
                    config=AthenaAssistantConfig(
                        enabled_tools=[Tool.SEARCH],
                    ),
                    messages=[],
                )
            ],
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/agents/athena-assistant/batch",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(typing.List[AthenaAssistantReponse], _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def invoke(
        self, *, request: AthenaAssistantRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> AthenaAssistantReponse:
        """
        Call the Athena Assistant agent synchronously.

        Call the agent with the messages list, wait for the agent to complete,
        and return the result.

        Parameters
        ----------
        request : AthenaAssistantRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AthenaAssistantReponse
            Successful Response

        Examples
        --------
        from athena import AthenaAssistantConfig, AthenaAssistantRequest, Tool
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.agents.athena_assistant.invoke(
            request=AthenaAssistantRequest(
                config=AthenaAssistantConfig(
                    enabled_tools=[Tool.SEARCH],
                ),
                messages=[],
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/agents/athena-assistant/invoke",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(AthenaAssistantReponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def stream_events(
        self, *, request: AthenaAssistantRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> AthenaAssistantReponse:
        """
        Call the Athena assistant and stream events.

        Parameters
        ----------
        request : AthenaAssistantRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AthenaAssistantReponse
            Successful Response

        Examples
        --------
        from athena import AthenaAssistantConfig, AthenaAssistantRequest, Tool
        from athena.client import AsyncAthena

        client = AsyncAthena(
            api_key="YOUR_API_KEY",
        )
        await client.agents.athena_assistant.stream_events(
            request=AthenaAssistantRequest(
                config=AthenaAssistantConfig(
                    enabled_tools=[Tool.SEARCH],
                ),
                messages=[],
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/v0/agents/athena-assistant/stream_events",
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(AthenaAssistantReponse, _response.json())  # type: ignore
        if _response.status_code == 422:
            raise UnprocessableEntityError(pydantic_v1.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)
